@@ -1,5 +1,5 @@
 package Curio;
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use Curio::Declare qw();
 use Curio::Role qw();
@@ -11,15 +11,21 @@ use strictures 2;
 use namespace::clean;
 
 sub import {
+    my ($class, %args) = @_;
+
     my $target = caller;
 
     Moo->import::into( 1 );
     Curio::Declare->import::into( 1 );
     namespace::clean->import::into( 1 );
 
+    my $role = 'Curio::Role';
+    $role = $args{role} if defined $args{role};
+    $role = "Curio::Role$role" if $role =~ m{^::};
+
     Moo::Role->apply_roles_to_package(
         $target,
-        'Curio::Role',
+        $role,
     );
 
     $target->initialize();
@@ -76,6 +82,8 @@ Create a Curio class:
     sub myapp_cache {
         return __PACKAGE__->fetch( @_ )->chi();
     }
+    
+    1;
 
 Then use your new Curio class elsewhere:
 
@@ -86,19 +94,19 @@ Then use your new Curio class elsewhere:
 =head1 DESCRIPTION
 
 Curio is a library for creating L<Moo> classes which encapsulate the
-construction and retrieval of arbitrary objects.  As a user of this
+construction and retrieval of arbitrary resources.  As a user of this
 library you've got two jobs.
 
 First, you create classes in your application which use Curio.  You'll
 have one class for each type of resource you want available to your
 application as a whole.  So, for example, you'd have a Curio class for
 your database connections, another for your graphite client, and perhaps
-a third for your AWS IAM clients.
+a third for your CRM client.
 
 Your second job is to then modify your application to use your Curio
 classes.  If your application uses an existing framework, such as
 L<Catalyst> or L<Dancer2>, then you may want to take a look at the
-available L</INTEGRATIONS>.  Also take a look at L</Use Curio Directly>.
+available L</INTEGRATIONS>.
 
 Keep in mind that Curio doesn't just have to be used for connections
 to remote services.  It can be used to make singleton classes, as a
@@ -111,6 +119,24 @@ The first versions of Curio that are hitting CPAN are early releases
 and may see major interface changes before things settle down.  This
 notice will be removed when that point is reached.
 
+=head1 IMPORT ARGUMENTS
+
+=head2 role
+
+    use Curio role => '::CHI';
+    use Curio role => 'Curio::Role::CHI';
+
+Set this to change the role that is applied to your Curio class.
+
+If the role you specify has a leading C<::> it is assumed to be
+relative to the C<Curio::Role> namespace and will have that appended
+to it.  So, if you set the role to C<::CHI> it will be automatically
+converted to C<Curio::Role::CHI>.
+
+See L</AVAILABLE ROLES> for a list of existing Curio roles.
+
+The default role is L<Curio::Role>.
+
 =head1 BOILERPLATE
 
 Near the top of most Curio classes is this line:
@@ -161,32 +187,18 @@ To not be tied into any single framework as is commonly done today.
 There is no reason this sort of logic needs to be framework dependent,
 and once it is it makes all sorts of things more difficult, such as
 migrating frameworks and writing in-house libraries that are framework
-independent.  Yes, Curio is a framework itself, but it is a very slim
-framework which gets out of your way quickly and is designed for this
-one purpose.
+independent.  Yes, Curio is a sort framework itself, but it is a very
+slim framework which gets out of your way quickly and is designed for
+this one purpose.
 
 =back
 
-These challenges can be solved by Curio and, by resolving them,
+These challenges can be solved by Curio and, by solving them,
 your applications will be more robust and resilient to change.
 
-=head1 INTEGRATIONS
+=head1 IMPORTANT PRACTICES
 
-=over
-
-=item *
-
-L<Catalyst::Model::Curio>
-
-=back
-
-If you don't see your framework here (L<Dancer2> I'm looking at
-you) then head down to L</SUPPORT> and open up an issue and lets
-get started on making one.
-
-=head1 BEST PRACTICES
-
-=head2 Avoid Holding onto Curio objects and Resources
+=head2 Avoid Holding onto Curio Objects and Resources
 
 Curio is designed to make it cheap to retrieve Curio objects
 and the underlying resources.  Take advantage of this.  Don't
@@ -206,27 +218,56 @@ It is tempting to use the L</INTEGRATIONS> such as
 L<Catalyst::Model::Curio>, and sometimes it is necessary to do so.
 Most of the time there is no need to add that extra layer of complexity.
 
-Continuing the Catalyst example, there are few reasons you can't
+Using Catalyst as an example, there are few reasons you can't
 just use your Curio classes directly from your Catalyst controllers.
 
-At ZipRecruiter, where we have massive Catalyst applications, we only
-wrap our Curio classes in Catalyst models in the few cases where other
-parts of Catalyst demand models be setup.  For the most part we bypass
-the model system completely and it makes everything much cleaner and
+At ZipRecruiter, where we have some massive Catalyst applications, we
+only use Catalyst models in the few cases where other parts of
+Catalyst demand that models be setup.  For the most part we bypass the
+model system completely and it makes everything much cleaner and
 easier to deal with.
 
-=head2 Purpose of Key Aliases
+=head2 Appropriate Uses of Key Aliases
 
 Key aliases are meant as a tool for migrating and merging keys.
-They are meant to be something you temporarly setup as you change
+They are meant to be something you temporarily setup as you change
 your code to use the new keys, and then once done you remove the
 aliases.
 
-It is tempting to use key aliases to provide simpler names for
-existing keys.  The problem with doing this is now you've
-introduced multiple keys for the same Curio objects which
-causes confusion and likely reduces grepability for the simpler
-names making it harder for developers to find.
+It can be tempting to use key aliases to provide simpler or alternative
+names for existing keys.  The problem with doing this is now you've
+introduced multiple keys for the same Curio class which in practice
+does cause unnecessary confusion.
+
+=head1 AVAILABLE ROLES
+
+These roles, available on CPAN, provide a base set of functionality
+for your Curio classes to wrap around specific resource types.
+
+=over
+
+=item *
+
+L<Curio::Role::CHI>
+
+=back
+
+Roles for L<DBI> and L<DBIx::Class> are in the works.
+
+=head1 INTEGRATIONS
+
+The CPAN modules listed here integrate Curio with other things
+such as web frameworks.
+
+=over
+
+=item *
+
+L<Catalyst::Model::Curio>
+
+=back
+
+On a related note, take a look at L</Use Curio Directly>.
 
 =head1 SEE ALSO
 
@@ -253,10 +294,6 @@ Curio GitHub issue tracker:
 
 L<https://github.com/bluefeet/Curio/issues>
 
-=head1 AUTHORS
-
-    Aran Clary Deltac <aran@bluefeet.dev>
-
 =head1 ACKNOWLEDGEMENTS
 
 Thanks to L<ZipRecruiter|https://www.ziprecruiter.com/>
@@ -264,10 +301,26 @@ for encouraging their employees to contribute back to the open
 source ecosystem.  Without their dedication to quality software
 development this distribution would not exist.
 
-=head1 LICENSE
+=head1 AUTHORS
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+    Aran Clary Deltac <aran@bluefeet.dev>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2019 Aran Clary Deltac
+
+This program is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see L<http://www.gnu.org/licenses/>.
 
 =cut
 
