@@ -1,5 +1,5 @@
 package Curio::Factory;
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 =encoding utf8
 
@@ -24,6 +24,7 @@ object" it is referring to instances of L</class>.
 =cut
 
 use Curio::Util;
+use Package::Stash;
 use Scalar::Util qw( blessed refaddr );
 use Types::Common::String qw( NonEmptySimpleStr );
 use Types::Standard qw( Bool Map HashRef );
@@ -40,6 +41,7 @@ sub BUILD {
     my ($self) = @_;
 
     $self->_store_class_to_factory();
+    $self->_install_fast_fetch_method();
 
     return;
 }
@@ -57,6 +59,22 @@ sub _store_class_to_factory {
     return;
 }
 
+sub _install_fast_fetch_method {
+    my ($self) = @_;
+
+    my $stash = Package::Stash->new( $self->class() );
+
+    $stash->add_symbol(
+        '&fetch',
+        sub{
+            shift;
+            return $self->fetch_curio( @_ );
+        },
+    );
+
+    return;
+}
+
 sub _process_key_arg {
     my ($self, $args) = @_;
 
@@ -343,6 +361,27 @@ has key_argument => (
     isa => NonEmptySimpleStr,
 );
 
+=head2 default_arguments
+
+    default_arguments => {
+        arg => 'value',
+        ...
+    },
+
+When set, these arguments will be used when creating new instances
+of the Curio class.
+
+Any other arguments such as those provided by L</add_key> and
+L</key_argument> will overwrite these default arguments.
+
+=cut
+
+has default_arguments => (
+    is      => 'rw',
+    isa     => HashRef,
+    default => sub{ {} },
+);
+
 =head1 ATTRIBUTES
 
 =head2 keys
@@ -477,15 +516,20 @@ sub arguments {
 sub _arguments {
     my ($self, $key) = @_;
 
-    return {} if !defined $key;
+    my $args = { %{ $self->default_arguments() } };
 
-    my %args = %{ $self->_keys->{$key} || {} };
+    return $args if !defined $key;
+
+    %$args = (
+        %$args,
+        %{ $self->_keys->{$key} || {} },
+    );
 
     if (defined $self->key_argument()) {
-        $args{ $self->key_argument() } = $key;
+        $args->{ $self->key_argument() } = $key;
     }
 
-    return \%args;
+    return $args;
 }
 
 =head2 add_key
@@ -589,7 +633,7 @@ sub inject {
     return;
 }
 
-=head1 uninject
+=head2 uninject
 
     my $curio_object = $factory->uninject();
     my $curio_object = $factory->uninject( $key );
@@ -678,9 +722,9 @@ See L<Curio/SUPPORT>.
 
 See L<Curio/AUTHORS>.
 
-=head1 LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-See L<Curio/LICENSE>.
+See L<Curio/COPYRIGHT AND LICENSE>.
 
 =cut
 
